translate.tools.pydiff.DirDiffer

Package translate :: Package tools :: Module pydiff :: Class DirDiffer |
[hide private]
[frames] | no frames]

# Class DirDiffer

source code

generates diffs between directories

Instance Methods | [hide private]
__init__(self, fromdir, todir, options) constructs a comparison between the two dirs using the given options | source code
isexcluded(self, difffile) checks if the given filename has been excluded from the diff | source code
writediff(self, outfile) writes the actual diff to the given file | source code